import type { AgentDependencies } from '../../agent/AgentDependencies';
import type { Logger } from '../../logger';
import type { FileSystem } from '../../storage/FileSystem';
import type { DidIndyNamespace } from '../../utils/indyIdentifiers';
import type * as Indy from 'indy-sdk';
import type { Subject } from 'rxjs';
export interface TransactionAuthorAgreement {
    version: `${number}.${number}` | `${number}`;
    acceptanceMechanism: string;
}
export interface IndyPoolConfig {
    genesisPath?: string;
    genesisTransactions?: string;
    id: string;
    isProduction: boolean;
    indyNamespace: DidIndyNamespace;
    transactionAuthorAgreement?: TransactionAuthorAgreement;
}
export declare class IndyPool {
    private indy;
    private logger;
    private fileSystem;
    private poolConfig;
    private _poolHandle?;
    private poolConnected?;
    authorAgreement?: AuthorAgreement | null;
    constructor(poolConfig: IndyPoolConfig, agentDependencies: AgentDependencies, logger: Logger, stop$: Subject<boolean>, fileSystem: FileSystem);
    get didIndyNamespace(): string;
    get id(): string;
    get config(): IndyPoolConfig;
    close(): Promise<void>;
    delete(): Promise<void>;
    connect(): Promise<number>;
    private connectToLedger;
    private submitRequest;
    submitReadRequest(request: Indy.LedgerRequest): Promise<Indy.LedgerReadReplyResponse>;
    submitWriteRequest(request: Indy.LedgerRequest): Promise<Indy.LedgerWriteReplyResponse>;
    private getPoolHandle;
    private getGenesisPath;
}
export interface AuthorAgreement {
    digest: string;
    version: string;
    text: string;
    ratification_ts: number;
    acceptanceMechanisms: AcceptanceMechanisms;
}
export interface AcceptanceMechanisms {
    aml: Record<string, string>;
    amlContext: string;
    version: string;
}
