import type { AgentContext } from '../../../agent';
import type { IndyPoolConfig } from '../IndyPool';
import type { CredDef, default as Indy, NymRole, Schema } from 'indy-sdk';
import { AgentDependencies } from '../../../agent/AgentDependencies';
import { Logger } from '../../../logger';
import { IndyIssuerService } from '../../indy/services/IndyIssuerService';
import { IndyPoolService } from './IndyPoolService';
export declare class IndyLedgerService {
    private indy;
    private logger;
    private indyIssuer;
    private indyPoolService;
    constructor(agentDependencies: AgentDependencies, logger: Logger, indyIssuer: IndyIssuerService, indyPoolService: IndyPoolService);
    setPools(poolConfigs: IndyPoolConfig[]): void;
    /**
     * @deprecated
     */
    getDidIndyWriteNamespace(): string;
    connectToPools(): Promise<number[]>;
    /**
     * @deprecated
     */
    registerPublicDid(agentContext: AgentContext, submitterDid: string, targetDid: string, verkey: string, alias: string, role?: NymRole): Promise<string>;
    /**
     * @deprecated
     */
    getPublicDid(agentContext: AgentContext, did: string): Promise<Indy.GetNymResponse>;
    /**
     * @deprecated
     */
    setEndpointsForDid(agentContext: AgentContext, did: string, endpoints: IndyEndpointAttrib): Promise<void>;
    /**
     * @deprecated
     */
    getEndpointsForDid(agentContext: AgentContext, did: string): Promise<IndyEndpointAttrib>;
    registerSchema(agentContext: AgentContext, did: string, schemaTemplate: SchemaTemplate): Promise<Schema>;
    getSchema(agentContext: AgentContext, schemaId: string): Promise<Indy.Schema>;
    registerCredentialDefinition(agentContext: AgentContext, did: string, credentialDefinitionTemplate: CredentialDefinitionTemplate): Promise<CredDef>;
    getCredentialDefinition(agentContext: AgentContext, credentialDefinitionId: string): Promise<CredDef>;
    getRevocationRegistryDefinition(agentContext: AgentContext, revocationRegistryDefinitionId: string): Promise<ParseRevocationRegistryDefinitionTemplate>;
    getRevocationRegistryDelta(agentContext: AgentContext, revocationRegistryDefinitionId: string, to?: number, from?: number): Promise<ParseRevocationRegistryDeltaTemplate>;
    getRevocationRegistry(agentContext: AgentContext, revocationRegistryDefinitionId: string, timestamp: number): Promise<ParseRevocationRegistryTemplate>;
}
export interface SchemaTemplate {
    name: string;
    version: string;
    attributes: string[];
}
export interface CredentialDefinitionTemplate {
    schema: Schema;
    tag: string;
    signatureType: 'CL';
    supportRevocation: boolean;
}
export interface ParseRevocationRegistryDefinitionTemplate {
    revocationRegistryDefinition: Indy.RevocRegDef;
    revocationRegistryDefinitionTxnTime: number;
}
export interface ParseRevocationRegistryDeltaTemplate {
    revocationRegistryDelta: Indy.RevocRegDelta;
    deltaTimestamp: number;
}
export interface ParseRevocationRegistryTemplate {
    revocationRegistry: Indy.RevocReg;
    ledgerTimestamp: number;
}
export interface IndyEndpointAttrib {
    endpoint?: string;
    types?: Array<'endpoint' | 'did-communication' | 'DIDComm'>;
    routingKeys?: string[];
    [key: string]: unknown;
}
