"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.V2PresentationMessage = void 0;
const class_transformer_1 = require("class-transformer");
const class_validator_1 = require("class-validator");
const AgentMessage_1 = require("../../../../../agent/AgentMessage");
const Attachment_1 = require("../../../../../decorators/attachment/Attachment");
const AriesFrameworkError_1 = require("../../../../../error/AriesFrameworkError");
const messageType_1 = require("../../../../../utils/messageType");
const uuid_1 = require("../../../../../utils/uuid");
const ProofFormatSpec_1 = require("../../../models/ProofFormatSpec");
class V2PresentationMessage extends AgentMessage_1.AgentMessage {
    constructor(options) {
        var _a, _b;
        super();
        this.type = V2PresentationMessage.type.messageTypeUri;
        this.lastPresentation = true;
        if (options) {
            this.formats = [];
            this.presentationsAttach = [];
            this.id = (_a = options.id) !== null && _a !== void 0 ? _a : uuid_1.uuid();
            this.comment = options.comment;
            this.goalCode = options.goalCode;
            this.lastPresentation = (_b = options.lastPresentation) !== null && _b !== void 0 ? _b : true;
            for (const entry of options.attachmentInfo) {
                this.addPresentationsAttachment(entry);
            }
        }
    }
    addPresentationsAttachment(attachment) {
        this.formats.push(attachment.format);
        this.presentationsAttach.push(attachment.attachment);
    }
    /**
     * Every attachment has a corresponding entry in the formats array.
     * This method pairs those together in a {@link ProofAttachmentFormat} object.
     */
    getAttachmentFormats() {
        const attachmentFormats = [];
        this.formats.forEach((format) => {
            const attachment = this.presentationsAttach.find((attachment) => attachment.id === format.attachmentId);
            if (!attachment) {
                throw new AriesFrameworkError_1.AriesFrameworkError(`Could not find a matching attachment with attachmentId: ${format.attachmentId}`);
            }
            attachmentFormats.push({ format, attachment });
        });
        return attachmentFormats;
    }
}
V2PresentationMessage.type = messageType_1.parseMessageType('https://didcomm.org/present-proof/2.0/presentation');
__decorate([
    messageType_1.IsValidMessageType(V2PresentationMessage.type),
    __metadata("design:type", Object)
], V2PresentationMessage.prototype, "type", void 0);
__decorate([
    class_validator_1.IsString(),
    class_validator_1.IsOptional(),
    __metadata("design:type", String)
], V2PresentationMessage.prototype, "comment", void 0);
__decorate([
    class_transformer_1.Expose({ name: 'goal_code' }),
    class_validator_1.IsString(),
    class_validator_1.IsOptional(),
    __metadata("design:type", String)
], V2PresentationMessage.prototype, "goalCode", void 0);
__decorate([
    class_transformer_1.Expose({ name: 'last_presentation' }),
    class_validator_1.IsBoolean(),
    __metadata("design:type", Object)
], V2PresentationMessage.prototype, "lastPresentation", void 0);
__decorate([
    class_transformer_1.Expose({ name: 'formats' }),
    class_transformer_1.Type(() => ProofFormatSpec_1.ProofFormatSpec),
    class_validator_1.IsArray(),
    class_validator_1.ValidateNested({ each: true }),
    class_validator_1.IsInstance(ProofFormatSpec_1.ProofFormatSpec, { each: true }),
    __metadata("design:type", Array)
], V2PresentationMessage.prototype, "formats", void 0);
__decorate([
    class_transformer_1.Expose({ name: 'presentations~attach' }),
    class_transformer_1.Type(() => Attachment_1.Attachment),
    class_validator_1.IsArray(),
    class_validator_1.ValidateNested({ each: true }),
    class_validator_1.IsInstance(Attachment_1.Attachment, { each: true }),
    __metadata("design:type", Array)
], V2PresentationMessage.prototype, "presentationsAttach", void 0);
exports.V2PresentationMessage = V2PresentationMessage;
//# sourceMappingURL=V2PresentationMessage.js.map